summaryrefslogtreecommitdiff
path: root/tests/i915/sysfs_heartbeat_interval.c
diff options
context:
space:
mode:
authorChris Wilson <chris@chris-wilson.co.uk>2020-12-31 09:51:58 +0000
committerChris Wilson <chris@chris-wilson.co.uk>2020-12-31 09:51:58 +0000
commita5c54153a82fe4cbd3b72cd85eb1b3eea91a1155 (patch)
treedae9c6cc9fc868bb9de1f1a55e68375245d0167b /tests/i915/sysfs_heartbeat_interval.c
parentde96eb1b5a0fe1ac799871ce07d663e6849841fa (diff)
i915/sysfs_heartbeat_interval: Tweak overhead allowance
The slow skl took 300ms just to print the ring/context state to dmesg upon detecting a hang. It appears we need to allow even more leeway before declaring the system broken. Signed-off-by: Chris Wilson <chris@chris-wilson.co.uk> Acked-by: Mika Kuoppala <mika.kuoppala@linux.intel.com>
Diffstat (limited to 'tests/i915/sysfs_heartbeat_interval.c')
-rw-r--r--tests/i915/sysfs_heartbeat_interval.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/i915/sysfs_heartbeat_interval.c b/tests/i915/sysfs_heartbeat_interval.c
index 8270ee7e..b8aba241 100644
--- a/tests/i915/sysfs_heartbeat_interval.c
+++ b/tests/i915/sysfs_heartbeat_interval.c
@@ -262,10 +262,10 @@ static void test_nopreempt(int i915, int engine)
/*
* It takes a few missed heartbeats before we start
* terminating hogs, and a little bit of jiffie slack for
* scheduling at each step. 250ms should cover all of our
* sins and be useful tolerance.
*/
- igt_assert_f(elapsed / 1000 / 1000 < 5 * delays[i] + 250,
+ igt_assert_f(elapsed / 1000 / 1000 < 5 * delays[i] + 500,
"Heartbeat interval (and CPR) exceeded request!\n");
}
@@ -448,7 +448,7 @@ static void test_off(int i915, int engine)
set_heartbeat(engine, 1);
- igt_assert_eq(sync_fence_wait(spin->out_fence, 250), 0);
+ igt_assert_eq(sync_fence_wait(spin->out_fence, 500), 0);
igt_assert_eq(sync_fence_status(spin->out_fence), -EIO);
igt_spin_free(i915, spin);
@@ -262,10 +262,10 @@ static void test_nopreempt(int i915, int engine)
* It takes a few missed heartbeats before we start
* terminating hogs, and a little bit of jiffie slack for
- * scheduling at each step. 250ms should cover all of our
- * sins and be useful tolerance.
+ * scheduling at each step. 500ms should cover all of our
+ * sins (including debug dumps) and be useful tolerance.
*/